@@ -47,12 +47,12 @@ my %CONFIG = (
         class    => 'Test::Smoke::Poster::LWP_UserAgent',
     },
     'HTTP::Tiny' => {
-        allowed => [],
+        allowed => [qw/ua_timeout/],
         required => [],
         class => 'Test::Smoke::Poster::HTTP_Tiny',
     },
     'curl' => {
-        allowed => [qw/curlbin/],
+        allowed => [qw/curlbin ua_timeout/],
         required => [qw/curlbin/],
         class => 'Test::Smoke::Poster::Curl',
     },
