@@ -204,7 +204,8 @@ sub Configure_win32 {
         "-Udefault_inc_excludes_dot" => "DEFAULT_INC_EXCLUDES_DOT",
         "-UWIN64"                    => "WIN64",
         "-Uusethreads"               => "USE_ITHREADS",
-        "-Uuseithraeds"              => "USE_ITHREADS",
+        "-Uuseithreads"              => "USE_ITHREADS",
+        "-UUSE_MINGW_ANSI_STDIO"     => "USE_MINGW_ANSI_STDIO",
         "-DDEBUGGING"                => "USE_DEBUGGING",
         "-DINST_DRV"                 => "INST_DRV",
         "-DINST_TOP"                 => "INST_TOP",
@@ -243,6 +244,7 @@ sub Configure_win32 {
         WIN64                    => 1,
         USE_SITECUST             => 0,
         DEFAULT_INC_EXCLUDES_DOT => 1,
+        USE_MINGW_ANSI_STDIO     => 1,
         USE_DEBUGGING            => 0,
         INST_DRV                 => undef,
         INST_TOP                 => undef,
@@ -680,10 +682,12 @@ sub set_local_patch {
     open PLIN,  "< $plh" or return 0;
     open PLOUT, "> $pln" or return 0;
     my $seen=0;
+    my $done=0;
     while ( <PLIN> ) {
-        if ( /\t,NULL/ and $seen ) {
+        if ( /^(\s+),NULL/ and $seen ) {
+            $done++;
             while ( my $c = shift @descr ) {
-                print PLOUT qq{\t,"$c"\n};
+                print PLOUT qq{$1,"$c"\n};
            }
         }
         $seen++ if /local_patches\[\]/;
@@ -692,6 +696,12 @@ sub set_local_patch {
     close PLIN;
     close PLOUT or return 0;
 
+    if ( not $done ) {
+        require Carp;
+        Carp::carp("Failed to update patchlevel.h. Content not as expected?");
+        return 0;
+    }
+
     -e $plb and 1 while unlink $plb;
     my $errno = "$!";
     if ( -e $plb ) {
